@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+import asyncio
 from asyncio import Future, wait_for
 
 import pytest
@@ -10,10 +11,12 @@ try:
 except ImportError:
     from concurrent.futures import TimeoutError  # type: ignore
 
-from mock import Mock
+from unittest.mock import Mock
+
 from twisted.internet.defer import succeed
 
-from pyee import AsyncIOEventEmitter, TwistedEventEmitter
+from pyee.asyncio import AsyncIOEventEmitter
+from pyee.twisted import TwistedEventEmitter
 
 
 class PyeeTestError(Exception):
@@ -40,6 +43,9 @@ async def test_asyncio_emit(event_loop):
 
     assert result is True
 
+    await asyncio.sleep(0)
+    assert len(ee._waiting) == 0
+
 
 @pytest.mark.asyncio
 async def test_asyncio_once_emit(event_loop):
